/**********************************************************************
audio i/o streams (.au format)

$Id: austream.h,v 1.3 2000/06/06 23:25:27 purnhage Exp $

Header file: austream.h

Authors:
HP    Heiko Purnhagen, Uni Hannover <purnhage@tnt.uni-hannover.de>
NM    Nikolaus Meine, Uni Hannover <meine@tnt.uni-hannover.de>

Changes:
16-sep-98   HP/NM   born, based on au_io.c
06-jun-00   HP      added non-blocking i/o: AuOpenReadNB(), AuOpenWriteNB()
**********************************************************************/

/* Audio i/o streaming with stdin/stdout support. */
/* Header format: .au (Sun audio file format, aka SND or AFsp) */
/* Sample format: 16 bit twos complement, uniform quantisation */
/* Data size set to -1 (=unknown) */

/* Multi channel data is interleaved: l0 r0 l1 r1 ... */
/* Total number of samples (over all channels) is used. */


#ifndef _austream_h_
#define _austream_h_


/* ---------- declarations ---------- */

typedef struct AuStreamStruct AuStream;	/* audio stream handle */


/* ---------- functions ---------- */

#ifdef __cplusplus
extern "C" {
#endif


/* AuInit() */
/* Init audio i/o streams. */

void AuInit (
  int debugLevel);		/* in: debug level */
				/*     0=off  1=basic  2=full */


/* AuOpenRead() */
/* Open audio stream for reading. */

AuStream *AuOpenRead (
  char *streamName,		/* in: stream name, "-" for stdin */
  int *numChannel,		/* out: number of channels */
  float *fSample,		/* out: sampling frequency [Hz] */
  long *numSample);		/* out: number of samples in stream */
				/*      or -1 if not available */
				/* returns: */
				/*  audio stream (handle) */
				/*  or NULL if error */


/* AuOpenWrite() */
/* Open audio stream for writing. */

AuStream *AuOpenWrite (
  char *streamName,		/* in: stream name, "-" for stdout */
  int numChannel,		/* in: number of channels */
  float fSample);		/* in: sampling frequency [Hz] */
				/* returns: */
				/*  audio stream (handle) */
				/*  or NULL if error */


/* AuOpenReadNB() */
/* Open audio stream for reading, non-blocking mode possible. */

AuStream *AuOpenReadNB (
  char *streamName,		/* in: stream name, "-" for stdin */
  int nonBlocking,		/* in: 1 for non-blocking mode */
  int *numChannel,		/* out: number of channels */
  float *fSample,		/* out: sampling frequency [Hz] */
  long *numSample);		/* out: number of samples in stream */
				/*      or -1 if not available */
				/* returns: */
				/*  audio stream (handle) */
				/*  or NULL if error */


/* AuOpenWriteNB() */
/* Open audio stream for writing, non-blocking mode possible. */

AuStream *AuOpenWriteNB (
  char *streamName,		/* in: stream name, "-" for stdout */
  int nonBlocking,		/* in: 1 for non-blocking mode */
  int numChannel,		/* in: number of channels */
  float fSample);		/* in: sampling frequency [Hz] */
				/* returns: */
				/*  audio stream (handle) */
				/*  or NULL if error */


/* AuReadData() */
/* Read data from audio stream. */
/* if non-blocking: fill with 0 if samples can not be read */

long AuReadData (
  AuStream *stream,		/* in: audio stream (handle) */
  short *data,			/* out: data[] */
  long numSample);		/* in: number of samples to be read */
				/* returns: */
				/*  number of samples read */


/* AuWriteData() */
/* Write data to audio stream. */
/* if non-blocking: discard samples that could not be written */

void AuWriteData (
  AuStream *stream,		/* in: audio stream (handle) */
  short *data,			/* in: data[] */
  long numSample);		/* in: number of samples to be written */


/* AuClose() */
/* Close audio stream.*/

void AuClose (
  AuStream *stream);		/* in: audio stream (handle) */


#ifdef __cplusplus
}
#endif

#endif	/* #ifndef _austream_h_ */

/* end of austream.h */

